bricklayer_fetch_parse_siu: Fetch and parse one SIU director's report

View source: R/parse_siu.R

bricklayer_fetch_parse_siuR Documentation

Fetch and parse one SIU director's report

Description

Convenience: bricklayer_fetch_siu() then bricklayer_parse_siu(). Fails gracefully – returns NULL with a message when the report cannot be retrieved.

Usage

bricklayer_fetch_parse_siu(drid, lang = c("en", "fr"))

Arguments

drid

Director's-report id (the ⁠drid=⁠ query parameter).

lang

"en" (default) or "fr".

Value

A named character vector of parsed fields, or NULL when the fetch fails.

Examples


f <- try(bricklayer_fetch_parse_siu(648), silent = TRUE)
if (is.character(f)) f[["police_service"]]


rmoriebricklayer documentation built on Aug. 5, 2026, 9:08 a.m.